#[non_exhaustive]pub enum CicpRange {
Narrow,
Full,
}Expand description
The values of this enumeration describe whether image data uses the full range of 8-bit values.
In digital broadcasting, it is common to reserve the lowest and highest values. Typically the allowed values for the narrow range are 16-235 for Y and 16-240 for u,v (when dealing with YUV data).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Narrow
The values use the range of 16-235 (for Y) and 16-240 for u and v.
Full
The values use the full range.