#[non_exhaustive]pub enum FrameResult {
Preparing,
Skipped,
Empty,
Submitted,
Outstanding,
Discarded,
Presented,
}v4_24 only.Expand description
An enumeration describing the process of rendering a frame. Rendering a frame starts with the frame clock cycle and then follows the rendered frame (if there was one) through the display server until it appears on screen.
It is relevant in particular for FrameTimings which
may still be waiting for values to be filled in.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Preparing
The frame is currently being prepared and rendered by GTK. This is the initial state.
Skipped
GTK has determined that nothing needs to be rendered because there are no visual changes. No rendering will be submitted to the display server and because of that no information will be forthcoming from the display server.
The frame is complete.
Empty
GTK has determined that nothing needs to be rendered because there are no visual changes. This information has been submitted to the display server. The presentation time has been updated to reflect when this frame would have been displayed.
The frame is complete.
Submitted
A frame has been drawn and submitted to the display server, but the display server will not provide any further feedback about when or how the frame is going to be displayed.
The frame is complete.
Outstanding
The frame has been drawn and submitted to the display server, but the display server has not yet replied what is going to happen with the rendered image.
Discarded
The frame has been drawn and submitted to the display server, but the display server has not displayed it. No presentation time will be available.
The frame is complete.
Presented
The frame has been drawn and submitted to the display server, and the display server has rendered it and displayed the result. The presentation time is accurately reflecting when that happened.
The frame is complete.