DevicePadExt

Trait DevicePadExt 

pub trait DevicePadExt: IsA<DevicePad> + 'static {
    // Provided methods
    fn feature_group(&self, feature: DevicePadFeature, feature_idx: i32) -> i32 { ... }
    fn group_n_modes(&self, group_idx: i32) -> i32 { ... }
    fn n_features(&self, feature: DevicePadFeature) -> i32 { ... }
    fn n_groups(&self) -> i32 { ... }
}
Trait containing all DevicePad methods.

Implementors

DevicePad

Provided Methods

fn feature_group(&self, feature: DevicePadFeature, feature_idx: i32) -> i32

Returns the group the given @feature and @idx belong to.

f the feature or index do not exist in @self, -1 is returned.

feature

the feature type to get the group from

feature_idx

the index of the feature to get the group from

Returns

The group number of the queried pad feature.

fn group_n_modes(&self, group_idx: i32) -> i32

Returns the number of modes that @group may have.

group_idx

group to get the number of available modes from

Returns

The number of modes available in @group.

fn n_features(&self, feature: DevicePadFeature) -> i32

Returns the number of features a tablet pad has.

feature

a pad feature

Returns

The amount of elements of type @feature that this pad has.

fn n_groups(&self) -> i32

Returns the number of groups this pad device has.

Pads have at least one group. A pad group is a subcollection of buttons/strip/rings that is affected collectively by a same current mode.

Returns

The number of button/ring/strip groups in the pad.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors