SurfaceExtManual

Trait SurfaceExtManual 

pub trait SurfaceExtManual: IsA<Surface> + 'static {
    // Provided methods
    fn create_similar_surface(
        &self,
        content: Content,
        width: i32,
        height: i32,
    ) -> Surface { ... }
    fn translate_coordinates(&self, to: &Surface, x: f64, y: f64) -> bool { ... }
}
Trait containing manually implemented methods of Surface.

Provided Methods

fn create_similar_surface( &self, content: Content, width: i32, height: i32, ) -> Surface

surface if @other is already in an error state or any other error occurs.

Deprecated since 4.12

Create a suitable cairo image surface yourself

content

the content for the new surface

width

width of the new surface

height

height of the new surface

Returns

a pointer to the newly allocated surface. The caller owns the surface and should call cairo_surface_destroy() when done with it.

fn translate_coordinates(&self, to: &Surface, x: f64, y: f64) -> bool

Translates coordinates between two surfaces.

Note that this only works if @to and @self are popups or transient-for to the same toplevel (directly or indirectly).

to

the target surface

Returns

true if the coordinates were successfully translated

x

coordinates to translate

y

coordinates to translate

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors