pub struct Device { /* private fields */ }Expand description
Represents an input device, such as a keyboard, mouse or touchpad.
See the Seat documentation for more information
about the various kinds of devices, and their relationships.
This is an Abstract Base Class, you cannot instantiate it.
Properties
active-layout-index
The index of the keyboard active layout of a Device.
Will be -1 if there is no valid active layout.
This is only relevant for keyboard devices.
Value changes from compositor events, connect to notify if needed.
Readable
caps-lock-state
Whether Caps Lock is on.
This is only relevant for keyboard devices.
Readable
direction
The direction of the current layout.
This is only relevant for keyboard devices.
Readable
display
The Display the Device pertains to.
Readable | Writable | Construct Only
has-bidi-layouts
Whether the device has both right-to-left and left-to-right layouts.
This is only relevant for keyboard devices.
Readable
has-cursor
Whether the device is represented by a cursor on the screen.
Readable | Writable | Construct Only
layout-names
The names of the keyboard layouts of a Device.
This is only relevant for keyboard devices.
Value changes from compositor events, connect to notify if needed.
Readable
modifier-state
The current modifier state of the device.
This is only relevant for keyboard devices.
Readable
n-axes
Number of axes in the device.
Readable
name
The device name.
Readable | Writable | Construct Only
num-lock-state
Whether Num Lock is on.
This is only relevant for keyboard devices.
Readable
num-touches
The maximal number of concurrent touches on a touch device.
Will be 0 if the device is not a touch device or if the number of touches is unknown.
Readable | Writable | Construct Only
product-id
Product ID of this device.
Readable | Writable | Construct Only
scroll-lock-state
Whether Scroll Lock is on.
This is only relevant for keyboard devices.
Readable
seat
Seat of this device.
Readable | Writable
source
Source type for the device.
Readable | Writable | Construct Only
tool
The DeviceTool that is currently used with this device.
Readable
vendor-id
Vendor ID of this device.
Readable | Writable | Construct Only
Signals
changed
Emitted either when the number of either axes or keys changes.
On X11 this will normally happen when the physical device routing events through the logical device changes (for example, user switches from the USB mouse to a tablet); in that case the logical device will change to reflect the axes and keys on the new physical device.
tool-changed
Emitted on pen/eraser devices whenever tools enter or leave proximity.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations