pub struct Monitor { /* private fields */ }Expand description
Represents the individual outputs that are associated with a Display.
Display keeps a GListModel to enumerate and monitor
monitors with DisplayExt::monitors(). You can use
DisplayExt::monitor_at_surface() to find a particular
monitor.
Properties
connector
The connector name.
Readable
description
A short description of the monitor, meant for display to the user.
Readable
display
The Display of the monitor.
Readable | Writable | Construct Only
geometry
The geometry of the monitor.
Readable
height-mm
The height of the monitor, in millimeters.
Readable
manufacturer
The manufacturer name.
Readable
model
The model name.
Readable
refresh-rate
The refresh rate, in milli-Hertz.
Readable
scale
The scale of the monitor.
Readable
scale-factor
The scale factor.
The scale factor is the next larger integer,
compared to scale.
Readable
subpixel-layout
The subpixel layout.
Readable
valid
Whether the object is still valid.
Readable
width-mm
The width of the monitor, in millimeters.
Readable
Signals
invalidate
Emitted when the output represented by @monitor gets disconnected.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations