pub struct Popup { /* private fields */ }Expand description
A surface that is attached to another surface.
The Popup is positioned relative to its parent surface.
Popups are typically used to implement menus and similar popups.
They can be modal, which is indicated by the autohide
property.
Properties
autohide
Whether to hide on outside clicks.
Readable | Writable | Construct Only
parent
The parent surface.
Readable | Writable | Construct Only
Surface
cursor
The mouse pointer for the Surface.
Readable | Writable
display
The Display connection of the surface.
Readable | Writable | Construct Only
frame-clock
The FrameClock of the surface.
Readable | Writable | Construct Only
height
The height of the surface, in pixels.
Readable
mapped
Whether the surface is mapped.
Readable
scale
The scale of the surface.
Readable
scale-factor
The scale factor of the surface.
The scale factor is the next larger integer,
compared to scale.
Readable
width
The width of the surface in pixels.
Readable
Implements
PopupExt, SurfaceExt, SurfaceExtManual
GLib type: GObject with reference counted clone semantics.
Implementations