pub struct Seat { /* private fields */ }Expand description
Represents a collection of input devices that belong to a user.
This is an Abstract Base Class, you cannot instantiate it.
Properties
display
Display of this seat.
Readable | Writable | Construct Only
Signals
device-added
Emitted when a new input device is related to this seat.
device-removed
Emitted when an input device is removed (e.g. unplugged).
tool-added
Emitted whenever a new tool is made known to the seat.
The tool may later be assigned to a device (i.e. on
proximity with a tablet). The device will emit the
tool-changed signal accordingly.
A same tool may be used by several devices.
tool-removed
Emitted whenever a tool is no longer known to this @seat.
Implements
GLib type: GObject with reference counted clone semantics.
Implementations