pub struct Texture { /* private fields */ }Expand description
Refers to pixel data in various forms.
It is primarily meant for pixel data that will not change over multiple frames, and will be used for a long time.
There are various ways to create Texture objects from a
[gdk_pixbuf::Pixbuf][crate::gdk_pixbuf::Pixbuf], or from bytes stored in memory, a file, or a
Gio::Resource.
The ownership of the pixel data is transferred to the Texture
instance; you can only make a copy of it, via TextureExtManual::download().
Texture is an immutable object: That means you cannot change
anything about it other than increasing the reference count via
GObject::Object::ref(), and consequently, it is a threadsafe object.
GDK provides a number of threadsafe texture loading functions:
from_resource(),
from_bytes(),
from_file(),
from_filename(),
for_pixbuf(). Note that these are meant for loading
icons and resources that are shipped with the toolkit or application. It
is recommended that you use a dedicated image loading framework such as
glycin, if you need to load untrusted image
data.
This is an Abstract Base Class, you cannot instantiate it.
Properties
color-state
The color state of the texture.
Readable | Writable | Construct Only
height
The height of the texture, in pixels.
Readable | Writable | Construct Only
width
The width of the texture, in pixels.
Readable | Writable | Construct Only
Implements
TextureExt, PaintableExt, [trait@gio::prelude::IconExt], [trait@gio::prelude::LoadableIconExt], TextureExtManual
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl Texture
impl Texture
pub const NONE: Option<&'static Texture> = None
Sourcepub fn for_pixbuf(pixbuf: &Pixbuf) -> Texture
👎Deprecated: Since 4.20
pub fn for_pixbuf(pixbuf: &Pixbuf) -> Texture
Since 4.20
Creates a new texture object representing the [gdk_pixbuf::Pixbuf][crate::gdk_pixbuf::Pixbuf].
This function is threadsafe, so that you can e.g. use GTask
and Gio::Task::run_in_thread() to avoid blocking the main
thread while loading a big image.
Deprecated since 4.20
Use e.g. libglycin, which can load many image
formats into a Texture
pixbuf
a [gdk_pixbuf::Pixbuf][crate::gdk_pixbuf::Pixbuf]
Returns
a new Texture
Sourcepub fn from_bytes(bytes: &Bytes) -> Result<Texture, Error>
pub fn from_bytes(bytes: &Bytes) -> Result<Texture, Error>
Creates a new texture by loading an image from memory,
The file format is detected automatically. The supported formats are PNG, JPEG and TIFF, though more formats might be available.
If NULL is returned, then @error will be set.
This function is threadsafe, so that you can e.g. use GTask
and Gio::Task::run_in_thread() to avoid blocking the main thread
while loading a big image.
::: warning
Note that this function should not be used with untrusted data.
Use a proper image loading framework such as libglycin, which can
load many image formats into a Texture.
bytes
a GBytes containing the data to load
Returns
A newly-created Texture
Sourcepub fn from_file(file: &impl IsA<File>) -> Result<Texture, Error>
pub fn from_file(file: &impl IsA<File>) -> Result<Texture, Error>
Creates a new texture by loading an image from a file.
The file format is detected automatically. The supported formats are PNG, JPEG and TIFF, though more formats might be available.
If NULL is returned, then @error will be set.
This function is threadsafe, so that you can e.g. use GTask
and Gio::Task::run_in_thread() to avoid blocking the main thread
while loading a big image.
::: warning
Note that this function should not be used with untrusted data.
Use a proper image loading framework such as libglycin, which can
load many image formats into a Texture.
file
GFile to load
Returns
A newly-created Texture
Sourcepub fn from_filename(path: impl AsRef<Path>) -> Result<Texture, Error>
pub fn from_filename(path: impl AsRef<Path>) -> Result<Texture, Error>
Creates a new texture by loading an image from a file.
The file format is detected automatically. The supported formats are PNG, JPEG and TIFF, though more formats might be available.
If NULL is returned, then @error will be set.
This function is threadsafe, so that you can e.g. use GTask
and Gio::Task::run_in_thread() to avoid blocking the main thread
while loading a big image.
::: warning
Note that this function should not be used with untrusted data.
Use a proper image loading framework such as libglycin, which can
load many image formats into a Texture.
path
the filename to load
Returns
A newly-created Texture
Sourcepub fn from_resource(resource_path: &str) -> Texture
pub fn from_resource(resource_path: &str) -> Texture
Creates a new texture by loading an image from a resource.
The file format is detected automatically. The supported formats are PNG, JPEG and TIFF, though more formats might be available.
It is a fatal error if @resource_path does not specify a valid
image resource and the program will abort if that happens.
If you are unsure about the validity of a resource, use
from_file() to load it.
This function is threadsafe, so that you can e.g. use GTask
and Gio::Task::run_in_thread() to avoid blocking the main thread
while loading a big image.
resource_path
the path of the resource file
Returns
A newly-created Texture