Struct
GdkTextureDownloader
Description [src]
struct GdkTextureDownloader {
/* No available fields */
}
The GdkTextureDownloader is used to download the contents of a
GdkTexture.
It is intended to be created as a short-term object for a single download, but can be used for multipe downloads of different textures or with different settings.
GdkTextureDownloader can be used to convert data between different formats.
Create a GdkTexture for the existing format and then download it in a
different format.
| Available since: | 4.10 |
Instance methods
gdk_texture_downloader_download_bytes
Downloads the given texture pixels into a GBytes. The rowstride will
be stored in the stride value.
Available since: 4.10
gdk_texture_downloader_free
Frees the given downloader and all its associated resources.
Available since: 4.10
gdk_texture_downloader_get_format
Gets the format that the data will be downloaded in.
Available since: 4.10
gdk_texture_downloader_get_texture
Gets the texture that the downloader will download.
Available since: 4.10
gdk_texture_downloader_set_format
Sets the format the downloader will download.
Available since: 4.10
gdk_texture_downloader_set_texture
Changes the texture the downloader will download.
Available since: 4.10