VulkanContext

Struct VulkanContext 

pub struct VulkanContext { /* private fields */ }
๐Ÿ‘ŽDeprecated:

Since 4.14

GTK does not expose any Vulkan internals. This struct is a leftover that was accidentally exposed. Represents the platform-specific Vulkan draw context.

VulkanContexts are created for a surface using SurfaceExt::create_vulkan_context(), and the context will match the characteristics of the surface.

Support for VulkanContext is platform-specific and context creation can fail, returning None context.

This is an Abstract Base Class, you cannot instantiate it.

Signals

images-updated

Emitted when the images managed by this context have changed.

Usually this means that the swapchain had to be recreated, for example in response to a change of the surface size.

Implements

DrawContextExt, DrawContextExtManual

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl VulkanContext

pub fn connect_images_updated<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

๐Ÿ‘ŽDeprecated:

Since 4.14

Emitted when the images managed by this context have changed.

Usually this means that the swapchain had to be recreated, for example in response to a change of the surface size.