Enumeration
GdkMemoryFormat
Description [src]
GdkMemoryFormat describes formats that image data can have in memory.
It describes formats by listing the contents of the memory passed to it.
So GDK_MEMORY_A8R8G8B8 will be 1 byte (8 bits) of alpha, followed by a
byte each of red, green and blue. It is not endian-dependent, so
CAIRO_FORMAT_ARGB32 is represented by different GdkMemoryFormats
on architectures with different endiannesses.
Its naming is modelled after VkFormat for details).
Members
-
GDK_MEMORY_B8G8R8A8_PREMULTIPLIED -
4 bytes; for blue, green, red, alpha. The color values are premultiplied with the alpha value.
- Value:
0 - Available since: 4.0
- Value:
-
GDK_MEMORY_A8R8G8B8_PREMULTIPLIED -
4 bytes; for alpha, red, green, blue. The color values are premultiplied with the alpha value.
- Value:
1 - Available since: 4.0
- Value:
-
GDK_MEMORY_R8G8B8A8_PREMULTIPLIED -
4 bytes; for red, green, blue, alpha The color values are premultiplied with the alpha value.
- Value:
2 - Available since: 4.0
- Value:
-
GDK_MEMORY_B8G8R8A8 -
4 bytes; for blue, green, red, alpha.
- Value:
3 - Available since: 4.0
- Value:
-
GDK_MEMORY_A8R8G8B8 -
4 bytes; for alpha, red, green, blue.
- Value:
4 - Available since: 4.0
- Value:
-
GDK_MEMORY_R8G8B8A8 -
4 bytes; for red, green, blue, alpha.
- Value:
5 - Available since: 4.0
- Value:
-
GDK_MEMORY_A8B8G8R8 -
4 bytes; for alpha, blue, green, red.
- Value:
6 - Available since: 4.0
- Value:
-
GDK_MEMORY_R8G8B8 -
3 bytes; for red, green, blue. The data is opaque.
- Value:
7 - Available since: 4.0
- Value:
-
GDK_MEMORY_B8G8R8 -
3 bytes; for blue, green, red. The data is opaque.
- Value:
8 - Available since: 4.0
- Value:
-
GDK_MEMORY_R16G16B16 -
3 guint16 values; for red, green, blue. Since: 4.6.
- Value:
9 - Available since: 4.0
- Value:
-
GDK_MEMORY_R16G16B16A16_PREMULTIPLIED -
4 guint16 values; for red, green, blue, alpha. The color values are premultiplied with the alpha value. Since: 4.6.
- Value:
10 - Available since: 4.0
- Value:
-
GDK_MEMORY_R16G16B16A16 -
4 guint16 values; for red, green, blue, alpha. Since: 4.6.
- Value:
11 - Available since: 4.0
- Value:
-
GDK_MEMORY_R16G16B16_FLOAT -
3 half-float values; for red, green, blue. The data is opaque. Since: 4.6.
- Value:
12 - Available since: 4.0
- Value:
-
GDK_MEMORY_R16G16B16A16_FLOAT_PREMULTIPLIED -
4 half-float values; for red, green, blue and alpha. The color values are premultiplied with the alpha value. Since: 4.6.
- Value:
13 - Available since: 4.0
- Value:
-
GDK_MEMORY_R16G16B16A16_FLOAT -
4 half-float values; for red, green, blue and alpha. Since: 4.6.
- Value:
14 - Available since: 4.0
- Value:
-
GDK_MEMORY_R32G32B32_FLOAT -
No description available.
- Value:
15 - Available since: 4.0
- Value:
-
GDK_MEMORY_R32G32B32A32_FLOAT_PREMULTIPLIED -
4 float values; for red, green, blue and alpha. The color values are premultiplied with the alpha value. Since: 4.6.
- Value:
16 - Available since: 4.0
- Value:
-
GDK_MEMORY_R32G32B32A32_FLOAT -
4 float values; for red, green, blue and alpha. Since: 4.6.
- Value:
17 - Available since: 4.0
- Value:
-
GDK_MEMORY_N_FORMATS -
The number of formats. This value will change as more formats get added, so do not rely on its concrete integer.
- Value:
18 - Available since: 4.0
- Value: